Coverage for denofo/utils/constants.py: 100%

1 class GoQBack:

2 """

3 Class to return if the user wants to go back to the previous question.

4 """

5

6 pass

7

8

9 SECTIONS = [

10 "input data",

11 "homology filter",

12 "non-coding homologs",

13 "evolutionary info",

14 "translational evidence",

15 "hyperlinks",

16]

17

18 ENCODE_DICT = {

19 "inputData": "A",

20 "inputAnnotGenome": "B",

21 "inputTranscriptome": "C",

22 "customInputData": "D",

23 "evolutionaryInformation": "E",

24 "homologyFilter": "F",

25 "nonCodingHomologs": "G",

26 "translationalEvidence": "H",

27 "studyURL": "I",

28 "AnnotGenome": "J",

29 "Transcriptome": "K",

30 "EvolutionaryInformation": "L",

31 "HomologyFilter": "M",

32 "NonCodingHomologs": "N",

33 "TranslationalEvidence": "O",

34 "translationEvidence": "P",

35 "customTranslationEvidence": "Q",

36 "selection": "R",

37 "enablingMutations": "S",

38 "SyntenySearch": "T",

39 "anchors": "U",

40 "customAnchor": "V",

41 "softwareSyntenySearch": "W",

42 "phylogeneticTaxa": "X",

43 "seqType": "Y",

44 "customSeqType": "Z",

45 "threshold": "a",

46 "customThreshold": "b",

47 "thresholdValue": "c",

48 "dataBase": "d",

49 "customDB": "e",

50 "PhylogeneticTaxa": "f",

51 "taxSpecificity": "g",

52 "taxonID": "h",

53 "TaxonID": "i",

54 "taxID": "j",

55 "expressionLevel": "k",

56 "transContextChoice": "l",

57 "customGeneticContext": "m",

58 "transORFChoice": "n",

59 "customORF": "o",

60 "transcriptomeInfo": "p",

61 "annotGenomeChoice": "q",

62 "synteny": "r",

63 "structuralSimilarity": "s",

64}

65

66 DECODE_DICT = {v: k for k, v in ENCODE_DICT.items()}

67

68 FUNCS_TO_MODELS_DICT = {

69 "q1": "inputData",

70 "q1_1": "annotGenomeChoice",

71 "q1_2": "inputTranscriptome",

72 "q1_2_1": "expressionLevel",

73 "q1_2_2": "transContextChoice",

74 "q1_2_3": "customGeneticContext",

75 "q1_2_4": "transORFChoice",

76 "q1_2_5": "customORF",

77 "q1_2_6": "answerTranscriptomeInfo",

78 "q1_2_7": "transcriptomeInfo",

79 "q1_3": "customInputData",

80 "q2": "homologyFilter",

81 "q2_1": "phylogeneticTaxa",

82 "q2_2": "taxSpecificity",

83 "q2_2_1": "taxID",

84 "q2_3": "seqType",

85 "q2_4": "customSeqType",

86 "q2_5_1": "QStructuralSimilarity",

87 "q2_5_2": "structuralSimilarity",

88 "q2_5_3": "threshold",

89 "q2_6": "customThreshold",

90 "q2_6_1": "thresholdValue",

91 "q2_7": "dataBase",

92 "q2_8": "customDB",

93 "q3": "nonCodingHomologs",

94 "q3_1": "enablingMutations",

95 "q3_2": "synteny",

96 "q3_3": "anchors",

97 "q3_3_1": "customAnchor",

98 "q3_3_2": "answerSoftwareSyntenySearch",

99 "q3_3_3": "softwareSyntenySearch",

100 "q4": "evolutionaryInformation",

101 "q4_1": "selection",

102 "q5": "translationalEvidence",

103 "q5_1": "translationEvidence",

104 "q5_2": "customTranslationEvidence",

105 "q6": "QstudyURL",

106 "q6_1": "studyURL",

107}

108

109 SUBMODELS = {

110 "DeNovoGeneAnnotation",

111 "AnnotGenome",

112 "Transcriptome",

113 "PhylogeneticTaxa",

114 "HomologyFilter",

115 "SyntenySearch",

116 "NonCodingHomologs",

117 "EvolutionaryInformation",

118 "TranslationalEvidence",

119}

120

121 REPLACEMENTS = {

122 "[": '["',

123 "]": '"]',

124 ",": '","',

125}

126

127 INDENT_LVL_DICT = {

128 "DeNovoGeneAnnotation": 0,

129 "inputData": 1,

130 "inputAnnotGenome": 2,

131 "AnnotGenome": 3,

132 "annotGenomeChoice": 3,

133 "inputTranscriptome": 2,

134 "Transcriptome": 2,

135 "expressionLevel": 3,

136 "transContextChoice": 3,

137 "customGeneticContext": 3,

138 "transORFChoice": 3,

139 "customORF": 3,

140 "transcriptomeInfo": 3,

141 "customInputData": 2,

142 "nonCodingHomologs": 1,

143 "translationalEvidence": 1,

144 "taxonID": 2,

145 "TaxonID": 2,

146 "HomologyFilter": 1,

147 "homologyFilter": 1,

148 "PhylogeneticTaxa": 2,

149 "phylogeneticTaxa": 2,

150 "taxSpecificity": 3,

151 "taxID": 3,

152 "seqType": 2,

153 "customSeqType": 2,

154 "structuralSimilarity": 2,

155 "threshold": 2,

156 "customThreshold": 2,

157 "thresholdValue": 2,

158 "dataBase": 2,

159 "customDB": 2,

160 "NonCodingHomologs": 1,

161 "enablingMutations": 2,

162 "synteny": 2,

163 "SyntenySearch": 2,

164 "anchors": 3,

165 "customAnchor": 3,

166 "softwareSyntenySearch": 3,

167 "EvolutionaryInformation": 1,

168 "evolutionaryInformation": 1,

169 "selection": 2,

170 "TranslationalEvidence": 1,

171 "translationEvidence": 2,

172 "customTranslationEvidence": 2,

173 "studyURL": 1,

174}